@@ -1,5 +1,4 @@
 #!/usr/bin/env bash
-
 web_port=30001
 core_port=8443
 SHELL_FOLDER=$(cd "$(dirname "$0")";pwd)
@@ -360,12 +359,12 @@ Would you like to continue the installation? [y/n] \033[0m"
 				sudo docker rm $container_core_id		
 			fi
 			
-			check_container_mongodb_id=`sudo docker ps -a |grep mongo:4.0.17 |cut -c 1-12|wc -l`
-			echo "message: $check_container_mongodb_id"
-			if [ $check_container_mongodb_id -eq 1 ]
+			check_container_postgredb_id=`sudo docker ps -a |grep postgres:16.1 |cut -c 1-12|wc -l`
+			echo "message: $check_container_postgredb_id"
+			if [ $check_container_postgredb_id -eq 1 ]
 				then
 				echo "start delete mognodb"					
-				container_core_id=`sudo docker ps -a |grep mongo:4.0.17 |cut -c 1-12`
+				container_core_id=`sudo docker ps -a |grep postgres:16.1 |cut -c 1-12`
 				sudo docker stop $container_core_id 		
 				sudo docker rm $container_core_id		
 			fi
@@ -429,66 +428,66 @@ fi
 echo -e "\033[32mweb image is existed\033[0m"
 
 
-echo -e "\033[36m(6/11)---- check old mongo ----\033[0m"
-check_running_container_mongo=`sudo docker ps -a|grep mongo:4.0.17|wc -l`
-check_running_container_mongo_dncSP=`sudo docker ps -a|grep mongo-dncSP|wc -l`
+echo -e "\033[36m(6/11)---- check old DB ----\033[0m"
+check_running_container_postgre=`sudo docker ps -a|grep postgres:16.1|wc -l`
+check_running_container_postgre_dncSP=`sudo docker ps -a|grep postgresql|wc -l`
 #check_docker_ps=`sudo docker ps -a`
 #echo $check_docker_ps
-echo "message: $check_running_container_mongo"
-#echo $check_running_container_mongo
-#echo $check_running_container_mongo_dncSP
-if [ $check_running_container_mongo -eq 1 ] && [ $check_running_container_mongo_dncSP -eq 1 ];
+echo "message: $check_running_container_postgre"
+#echo $check_running_container_postgre
+#echo $check_running_container_postgre_dncSP
+if [ $check_running_container_postgre -eq 1 ] && [ $check_running_container_postgre_dncSP -eq 1 ];
         then echo "Will you keep the old data? [y/n]"
         read k
         if [ "$k" = "y" ]; then
-                check_nuclias_connect_MONGO_DATA=`sudo docker volume ls|grep nuclias_connect_MONGO-DATA|wc -l`
-                if [ $check_nuclias_connect_MONGO_DATA -eq 1 ]
+                check_nuclias_connect_POSTGRES_DATA=`sudo docker volume ls|grep nuclias_connect_POSTGRES_DATA|wc -l`
+                if [ $check_nuclias_connect_POSTGRES_DATA -eq 1 ]
                         then
                         echo "The data volume already exists"
-                        echo "Start deleting mongo:4.0.17"
-                        mongo_container_id=`sudo docker ps -a|grep mongo-dncSP|cut -c 1-12`
-                        sudo docker stop $mongo_container_id
-                        sudo docker rm $mongo_container_id
-                        sudo docker rmi mongo:4.0.17
+                        echo "Start deleting postgres:16.1"
+                        postgre_container_id=`sudo docker ps -a|grep postgresql|cut -c 1-12`
+                        sudo docker stop $postgre_container_id
+                        sudo docker rm $postgre_container_id
+                        sudo docker rmi postgres:16.1
                 fi
         elif [ "$k" = "n" ]; then
                 echo "Start deleting the data volume"
-                check_nuclias_connect_MONGO_DATA=`sudo docker volume ls|grep nuclias_connect_MONGO-DATA|wc -l`
-                if [ $check_nuclias_connect_MONGO_DATA -eq 1 ]
+                check_nuclias_connect_POSTGRES_DATA=`sudo docker volume ls|grep nuclias_connect_POSTGRES_DATA|wc -l`
+                if [ $check_nuclias_connect_POSTGRES_DATA -eq 1 ]
                         then
-                        sudo docker volume rm nuclias_connect_MONGO-DATA
+                        sudo docker volume rm nuclias_connect_POSTGRES_DATA
                 fi
         fi
 else
-        echo -e "\033[32mno such old mongoDB contianer\033[0m"
+        echo -e "\033[32mno such old postgreDB contianer\033[0m"
 fi
 
 
-echo -e "\033[36m(7/11)---- check mongo image ----\033[0m"
-check_image_mongo=`sudo docker images mongo:4.0.17 | wc -l`
-echo "message: $check_image_mongo"
-if [ $check_image_mongo -eq 1 ]
-	then echo "start find mongo image"
-	if [ ! -f $SHELL_FOLDER"/images/mongo.tar" ]
-		then echo -e "\033[31m not found mongo image\033[0m"
+echo -e "\033[36m(7/11)---- check DB image ----\033[0m"
+check_image_postgre=`sudo docker images postgres:16.1 | wc -l`
+echo "message: $check_image_postgre"
+if [ $check_image_postgre -eq 1 ]
+	then echo "start find postgreSQL image"
+	if [ ! -f $SHELL_FOLDER"/images/postgredb.tar" ]
+		then echo -e "\033[31m not found postgreSQL image\033[0m"
 		exit 1
 	fi
-load_mongo=`sudo docker load < $SHELL_FOLDER/images/mongo.tar`
+load_postgre=`sudo docker load < $SHELL_FOLDER/images/postgredb.tar`
 fi
-echo -e "\033[32mmongo image is existed\033[0m"
+echo -e "\033[32mpostgreSQL image is existed\033[0m"
 
 
 
 
-echo -e "\033[36m(8/11)---- check mongo_port ----\033[0m"
-for port in 27010 27017
+echo -e "\033[36m(8/11)---- check postgreSQL_port ----\033[0m"
+for port in 5432 5433
 do
-	check_mongo_port_free=`lsof -i:$port | wc -l`
-	echo "message: $check_mongo_port_free"
-	if [ $check_mongo_port_free -eq 0 ]
-		then echo -e "\033[32mmongo_port $port is free\033[0m"
+	check_postgre_port_free=`lsof -i:$port | wc -l`
+	echo "message: $check_postgre_port_free"
+	if [ $check_postgre_port_free -eq 0 ]
+		then echo -e "\033[32mpostgre_port $port is free\033[0m"
 	else
-		echo -e "\033[31mmongo_port $port is used\033[0m" 
+		echo -e "\033[31mpostgre_port $port is used\033[0m" 
 		exit 1
 	fi
 done
@@ -525,8 +524,8 @@ elif [ ! -f $SHELL_FOLDER"/appconfig.json" ]; then
 elif [ ! -f $SHELL_FOLDER"/config/systemconfig.json" ]; then
 	echo -e "\033[31mnot found /config/systemconfig.json\033[0m"
 	exit 1
-elif [ ! -f $SHELL_FOLDER"/entrypoint-initdb.sh" ]; then
-	echo -e "\033[31mnot found entrypoint-initdb.sh\033[0m"
+elif [ ! -f $SHELL_FOLDER"/entrypoint-initdb.sql" ]; then
+	echo -e "\033[31mnot found entrypoint-initdb.sql\033[0m"
 	exit 1
 fi
 if [ ! -d $SHELL_FOLDER"/customer" ]; then
@@ -558,8 +557,8 @@ sed -i "3c \  \"nucliasPath\":\""$SHELL_FOLDER"\"," $SHELL_FOLDER"/config/system
 echo -e "\033[32mcheck file finished\033[0m"
 echo -e "\033[32mall check_job finished\033[0m"
 
-check_nuclias_connect_MONGO_DATA=`sudo docker volume ls|grep nucliasconnect_MONGO-DAT|wc -l`
-if [ $check_nuclias_connect_MONGO_DATA -eq 0 ]
+check_nuclias_connect_POSTGRES_DATA=`sudo docker volume ls|grep nuclias_connect_POSTGRES_DATA|wc -l`
+if [ $check_nuclias_connect_POSTGRES_DATA -eq 0 ]
 	then  
 		echo ""
 		echo -e "\033[36mThe system will initial setup the database administrator account for Nuclias Connect, is this the first time to setup an administrator account? [y/n]\033[0m"
@@ -574,8 +573,8 @@ if [ $check_nuclias_connect_MONGO_DATA -eq 0 ]
 							echo -e "\033[31mConfirm password is not consistent\033[0m"
 							exit 1
 						else
-							sed -i "5c db.createUser({user:'"$name"', pwd:'"$pwd1"', roles:[{role:'root',db:'admin'}]});" $SHELL_FOLDER"/entrypoint-initdb.sh"
-							sed -i "6c db.auth('"$name"','"$pwd1"');" $SHELL_FOLDER"/entrypoint-initdb.sh"
+							sed -i "s/POSTGRES_USER: 'admin'/POSTGRES_USER: '$name'/g" $SHELL_FOLDER"/docker-compose.yml"
+							sed -i "s/POSTGRES_PASSWORD: 'admin'/POSTGRES_PASSWORD: '$pwd2'/g" $SHELL_FOLDER"/docker-compose.yml"
 						fi
 				else
 					echo -e "\033[31mThe input password is empty\033[0m"
